views

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2026 License: GPL-3.0 Imports: 19 Imported by: 0

Documentation

Overview

Package views provides the page content for the ChairLift application

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ToastAdder

type ToastAdder interface {
	ShowToast(message string)
	ShowErrorToast(message string)
	SetUpdateBadge(count int)
}

ToastAdder is an interface for adding toasts and notifying about updates

type UserHome

type UserHome struct {
	// contains filtered or unexported fields
}

UserHome manages all content pages

func New

func New(cfg *config.Config, toastAdder ToastAdder) *UserHome

New creates a new UserHome views manager

func (*UserHome) GetPage

func (uh *UserHome) GetPage(name string) *adw.ToolbarView

GetPage returns a page by name

Jump to