Documentation
¶
Overview ¶
Package views provides the page content for the ChairLift application
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ToastAdder ¶
type ToastAdder interface {
ShowToast(message string)
ShowErrorToast(message string)
SetUpdateBadge(count int)
}
ToastAdder is an interface for adding toasts and notifying about updates
Click to show internal directories.
Click to hide internal directories.